@@ -157,4 +157,4 @@ def run(browser=None):
     if os.environ.get('WERKZEUG_RUN_MAIN') != 'true':
         launch_browser(BROWSER)
     app.debug = settings.DEBUG
-    app.run(port=settings.HTTP_PORT)
+    app.run(host=settings.HTTP_HOST, port=settings.HTTP_PORT)
